@@ -2,7 +2,7 @@
 /**
  * Kronolith external API interface.
  *
- * $Horde: kronolith/lib/api.php,v 1.126.2.67 2010-05-09 19:00:32 mrubinsk Exp $
+ * $Horde: kronolith/lib/api.php,v 1.126.2.68 2011/07/02 17:25:08 jan Exp $
  *
  * This file defines Kronolith's external API interface. Other applications
  * can interact with Kronolith through this API.
@@ -973,6 +973,7 @@ function _kronolith_delete($uid)
         $ownerCalendars = Kronolith::listCalendars(true, PERMS_DELETE);
         foreach ($events as $ev) {
             if (Auth::isAdmin() || isset($ownerCalendars[$ev->getCalendar()])) {
+                $kronolith_driver->open($ev->getCalendar());
                 $event = $ev;
                 break;
             }
